/*
 * JORAM: Java(TM) Open Reliable Asynchronous Messaging
 * Copyright (C) 2022 ScalAgent Distributed Technologies
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA.
 *
 * Initial developer(s): ScalAgent Distributed Technologies
 * Contributor(s):
 */
package classic;

import javax.jms.*;
import javax.naming.*;

/**
 * Produces messages on the queue and on the topic.
 */
public class ProducerTest {
  static Context ictx = null; 

  public static void main(String[] args) throws Exception {
    System.out.println("Produces messages on " + args[0]);

    ictx = new InitialContext();
    Destination dest = (Destination) ictx.lookup(args[0]);
    ConnectionFactory cf = (ConnectionFactory) ictx.lookup("cf");
    ictx.close();

    String prefix = System.getProperty("JMSMessageID.prefix");
    if (prefix != null)
      System.setProperty("org.objectweb.joram.client.jms.messageid.prefix", prefix);
    Connection cnx = cf.createConnection();
    Session sess = cnx.createSession(false, Session.AUTO_ACKNOWLEDGE);
    MessageProducer producer = sess.createProducer(dest);

    Message msg = sess.createMessage();
    producer.send(msg);
    msg = sess.createTextMessage("Message Text");
    producer.send(msg);
    
    msg = sess.createBytesMessage();
    ((BytesMessage) msg).writeUTF("BytesMessage");
    producer.send(msg);
    
    msg = sess.createBytesMessage();
    ((BytesMessage) msg).writeBytes("BytesMessage with charset".getBytes("UTF-16"));
    producer.send(msg);

    msg = sess.createMapMessage();
    ((MapMessage) msg).setString("String", "MapMessage");
    ((MapMessage) msg).setBoolean("Boolean", true);
    ((MapMessage) msg).setInt("Integer", 10);
    producer.send(msg);
    
    msg = sess.createStreamMessage();
    ((StreamMessage) msg).writeString("MapMessage");
    ((StreamMessage) msg).writeBoolean(true);
    ((StreamMessage) msg).writeInt(10);
    producer.send(msg);
    
    msg = sess.createObjectMessage();
    ((ObjectMessage) msg).setObject("ObjectMessage");
    producer.send(msg);
    
    System.out.println("Messages sent.");

    cnx.close();
  }
}
